import getpass
import json
import os
import sys
import argparse


# Add the relative path to the python library
lib_path = os.path.abspath(os.path.join('python_bundle_1_2_2'))
sys.path.append(lib_path)

from mgmt_api_lib import cp_mgmt_api

def get_aws_regions(filename, group_name_prefix):
    aws_groups = set()
    # Open json document 
    with open(filename) as data_file:    
        data = json.load(data_file)
        print "Reading AWS regions from: " + filename
        for item in data["prefixes"]:
            region_name = group_name_prefix + item["region"]
            aws_groups.add(region_name)
    return aws_groups

def get_aws_networks(filename, network_name_prefix, group_name_prefix):
   aws_networks = {}
   with open(filename) as data_file:
       data = json.load(data_file)
       print "Reading AWS networks from: " + filename
       for item in data["prefixes"]:
           region_name = group_name_prefix + item["region"]
           cidr = item["ip_prefix"]
           cidr_split = cidr.split("/")
           network = cidr_split[0]
           mask_length = cidr_split[1]
           aws_networks[network_name_prefix + cidr] = {"subnet": network, "mask-length": mask_length, "groups" : region_name}
   return aws_networks

server = raw_input("Enter server IP address or hostname:")
username = raw_input("Enter username: ")
if sys.stdin.isatty():
      password = getpass.getpass("Enter password: ")
else:
      print "Attention! Your password will be shown on the screen!"
      password = raw_input("Enter password: ")

domain_name = raw_input("Domain name (leave empty for a SmartCenter environment): ")

aws_filename = raw_input("Azure data file (downloaded from https://ip-ranges.amazonaws.com/ip-ranges.json): ")

if aws_filename=="":
    aws_filename="ip-ranges.json"

if not os.path.exists(aws_filename):
	 print "Could not open data file!" + aws_filename
	 exit(1)
	  
with cp_mgmt_api.APIClient(cp_mgmt_api.APIClientArgs()) as client:
      client.debug_file = "api_calls.json"
      login_res = client.login(server, username, password, domain=domain_name)
      
      if login_res.success is False:
         print "login failed"
         exit(1)

      regions = get_aws_regions(aws_filename, "aws_region_")
      networks = get_aws_networks(aws_filename, "aws_network_", "aws_region_")
      
      print "Creating " + str(len(regions)) + " groups."

      for grp in regions:
         res = client.api_call("add-group",{"name": grp})
         #print grp + ": " + str(res.success)
      print "publish"
      res = client.api_call("publish",{})

      print "get existing list of aws_network_* objects"
      res = client.api_query("show-objects", "standard", "objects",True, {"type" :"network", "in" : ["name" , "aws_network_" ]})
      print "Found " + str(len(res.data["objects"])) + " networks"
      
      existing_networks = set()
      for existing_obj in res.data["objects"]:
         existing_networks.add(existing_obj["name"])

      print "networks: " + str(len(networks))
      i=0
      for network_name in networks:
         i=i+1
         if network_name not in existing_networks:
            print str(i) + " " + network_name
            res = client.api_call("add-network", {"name":network_name, "subnet": networks[network_name]["subnet"], "mask-length": networks[network_name]["mask-length"]})
            if i % 50 == 0:
                     print "publishing " + str(i) + " out of " + str(len(networks))
                     res = client.api_call("publish",{})
      
      print "Publishing last networks"
      res = client.api_call("publish",{})
      
      print "add networks to groups"
      for grp in regions:
         members = set()
         for network_name in networks:
            if networks[network_name]["groups"] == grp:
               members.add(network_name)
         print grp + ": " + str(len(members)) + " members"
         res = client.api_call("set-group",{"name": grp, "members" : list(members)})
      print "publish"
      res = client.api_call("publish",{})

      print "Create or update the 'aws_region_all' group"
      print ', '.join(regions)
      res = client.api_call("add-group",{"name": "aws_region_all"})
      res = client.api_call("set-group",{"name": "aws_region_all", "members" : list(regions) })
      print "publish"
      res = client.api_call("publish",{})

